NibiteDivider constructor

const NibiteDivider({
  1. Key? key,
  2. required String labelText,
  3. Color? labelTextColor,
  4. Color? dividerColor,
})

Creates a NibiteDivider with its initial values.

  • labelText: The text to be displayed in the center of the NibiteDivider.
  • labelTextColor: The color of the text to be displayed in the center of the NibiteDivider.
  • dividerColor: The color of the NibiteDivider.

Implementation

const NibiteDivider({
  super.key,
  required this.labelText,
  this.labelTextColor,
  this.dividerColor,
});