NibiteDivider constructor
const
NibiteDivider({})
Creates a NibiteDivider with its initial values.
labelText: The text to be displayed in the center of the NibiteDivider.labelTextColor: The color of the text to be displayed in the center of the NibiteDivider.dividerColor: The color of the NibiteDivider.
Implementation
const NibiteDivider({
super.key,
required this.labelText,
this.labelTextColor,
this.dividerColor,
});