NibiteSpinner constructor
const
NibiteSpinner({})
Creates a NibiteSpinner with its initial values.
resultValue: A Function to generally update a variable with the updated quantity.isRemovable: Whether or not to allow the left button to become a remove button when the quantity equals 1.initialValue: An initial value for the NibiteSpinner.suffix: A suffix that can be used as a unit of measurement.style: Styling for NibiteSpinner.
Implementation
const NibiteSpinner({
super.key,
required this.resultValue,
this.isRemovable = false,
required this.initialValue,
this.suffix = '',
this.style,
});